@@ -1,7 +1,7 @@
 # ABSTRACT: Subroutines for making simple command line scripts
 package CLI::Helpers;
 
-our $VERSION = 0.9;
+our $VERSION = '1.0';
 our $_OPTIONS_PARSED;
 
 use strict;
@@ -142,12 +142,12 @@ sub colorize {
 sub output {
     my $opts = ref $_[0] eq 'HASH' ? shift @_ : {};
 
-    # Input/output Arrays
-    my @input = @_;
-    my @output = ();
+    # Return unless we have something to work with;
+    return unless @_;
 
-    # Remove line endings
-    chomp(@input);
+    # Input/output Arrays
+    my @input = map { my $x=$_; chomp($x) if defined $x; $x; } @_;
+    my @output = ();
 
     # Determine the color
     my $color = exists $opts->{color} && defined $opts->{color} ? $opts->{color} : undef;
@@ -162,8 +162,9 @@ sub output {
         while( @input ) {
             my $k = shift @input;
             # We only colorize the value
-            my $v = colorize($color, shift @input );
-            push @output, join($DEF{KV_FORMAT}, $k, $v);
+            my $v = shift @input;
+            $v ||= $DEF{KV_FORMAT} eq ': ' ? '~' : '';
+            push @output, join($DEF{KV_FORMAT}, $k, colorize($color,$v));
         }
     }
     else {
@@ -407,7 +408,7 @@ CLI::Helpers - Subroutines for making simple command line scripts
 
 =head1 VERSION
 
-version 0.9
+version 1.0
 
 =head1 SYNOPSIS
 
